<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>GrandSearch::AiToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="46"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>无法使用%1，请先到应用商店更新UOS AI版本</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="47"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="48"/>
        <source>Open App Stroe</source>
        <translation>打开商店</translation>
    </message>
</context>
<context>
    <name>GrandSearch::AiToolBarInner</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="102"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="152"/>
        <source>Summary</source>
        <translation>文档总结</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="103"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="153"/>
        <source>Translation</source>
        <translation>文档翻译</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="104"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="154"/>
        <source>Extension</source>
        <translation>文档扩写</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="105"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="155"/>
        <source>Add to knowledge base</source>
        <translation>添加到知识库</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="116"/>
        <source>Summarize document content with UOS AI</source>
        <translation>用UOS AI总结文档内容</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="117"/>
        <source>Translate document content with UOS AI</source>
        <translation>用UOS AI翻译文档内容</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="118"/>
        <source>Extend document content with UOS AI</source>
        <translation>用UOS AI扩写文档内容</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="119"/>
        <source>Add document to UOS AI knowledge base</source>
        <translation>将文档添加到UOS AI知识库</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="390"/>
        <source>DDE Grand Search</source>
        <translation>全局搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="393"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>无法使用%1，请先到应用商店更新UOS AI版本</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="394"/>
        <source>Open App Stroe</source>
        <translation>打开商店</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="23"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="26"/>
        <source>Excluded path</source>
        <translation>路径黑名单</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="37"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation>可将不希望被搜索到的路径添加至黑名单中。</translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="26"/>
        <source>Custom search</source>
        <translation>个性化</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="42"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="86"/>
        <source>Grand Search</source>
        <translation>全局搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="149"/>
        <source>Search settings</source>
        <translation>搜索设置</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation>是否从路径黑名单中移出选中路径？</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="225"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="226"/>
        <source>What would you like to search for?</source>
        <translation>搜索想要查找的内容</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="78"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="193"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="204"/>
        <source>Time modified:</source>
        <translation>修改时间：</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="70"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="75"/>
        <source>Open Path</source>
        <translation>打开路径</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="80"/>
        <source>Copy Path</source>
        <translation>复制路径</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="288"/>
        <source>More</source>
        <translation>更多</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="324"/>
        <source>No search results</source>
        <translation>暂无搜索结果</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="25"/>
        <source>Index</source>
        <translation>索引</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IntelligentRetrievalWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="68"/>
        <source>When turned on, you can try to search for local documents using natural language descriptions, such as &quot;last week&apos;s documents&quot;.</source>
        <translation>开启后您可以尝试使用自然语言描述搜索本地文件，例如搜索“上周的文档”。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="141"/>
        <source>Intelligent full text search</source>
        <translation>智能全文检索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="85"/>
        <source>Automatic index update</source>
        <translation>自动更新索引</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="55"/>
        <source>AI Smart Search</source>
        <translation>AI智能搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="110"/>
        <source>UOS AI LLM</source>
        <translation>UOS AI大模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="110"/>
        <source>After installing the UOS AI large model, you can use the AI intelligent search function without an internet connection.</source>
        <translation>安装UOS AI大模型后，无需联网即可使用AI智能搜索功能</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="119"/>
        <source>Full Text Search</source>
        <translation>全文检索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="127"/>
        <source>When turned on, full text search can be used in the file manager and grand search.</source>
        <translation>开启后，在系统文件管理器和全局搜索内均可使用全文检索功能</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="173"/>
        <source>When enabled, you can search the text of articles using disjointed and incomplete keywords.</source>
        <translation>开启后您可以使用不连贯、不完整的关键词搜索文章文本内容。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="195"/>
        <source>Please install %0 in &lt;a href=&quot;%0&quot;&gt;the app store&lt;/a&gt; before turning on this configuration.</source>
        <translation>请先到 &lt;a href=&quot;%0&quot;&gt;应用商店&lt;/a&gt; 安装%0模型后再开启该配置。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="234"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="358"/>
        <source>Intelligent search indexing is being updated, which may take up more resources, please keep the power access.</source>
        <translation>正在更新智能搜索索引编制，可能占用较多资源，请保持电源接入。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="238"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="362"/>
        <source>Smart Search indexing update is complete. Last update time: %0</source>
        <translation>智能搜索索引编制更新完成。上次更新时间：%0</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="241"/>
        <source>Indexing error!</source>
        <translation>索引编制出错！</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="287"/>
        <source>To use AI smart search, you need to install the UOS AI large model. Please install the model.</source>
        <translation>使用AI智能搜索需要安装UOS AI大模型，请安装模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="288"/>
        <source>Not yet</source>
        <translation>暂不使用</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="289"/>
        <source>Install the model</source>
        <translation>安装模型</translation>
    </message>
</context>
<context>
    <name>GrandSearch::LLMWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="59"/>
        <source>NotInstalled</source>
        <translation>未安装</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="74"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="342"/>
        <source>Install Model</source>
        <translation>安装模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="90"/>
        <source>Update model</source>
        <translation>更新模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="91"/>
        <source>Uninstall model</source>
        <translation>卸载模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="146"/>
        <source>Installing</source>
        <translation>安装中</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="211"/>
        <source>Are you sure you want to delete this model?</source>
        <translation>确定卸载UOS AI大模型？</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="212"/>
        <source>After uninstallation, functions such as AI Search and UOS AI Assistant will not work properly.</source>
        <translation>卸载后将导致AI搜索、UOS AI助手等功能无法正常使用。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="213"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>暂不卸载</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="214"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>确定卸载</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="337"/>
        <source>UnInstall Model</source>
        <translation>卸载模型</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="338"/>
        <source>Installed</source>
        <translation>已安装</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="343"/>
        <source>Not Installed</source>
        <translation>未安装</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="208"/>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="83"/>
        <source>Guess you want to search the following</source>
        <translation>猜您想搜以下内容</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="27"/>
        <source>Search experience program</source>
        <translation>搜索体验计划</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="35"/>
        <source>Join search experience program</source>
        <translation>加入搜索体验计划</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="48"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations, the contents you search while using the Application, the time of search, the type of requested large model.If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>开启搜索体验计划，视为您授权我们收集与您的设备、系统、文件图标、部分文件内容、文件属性、应用软件及配置、搜索内容、搜索发起时间、搜索使用的AI模型名称等信息，您可以关闭搜索体验计划，以拒绝我们对前述信息的收集与使用。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="59"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>了解对数据的管理与使用方式，请参考统信软件隐私政策（</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="61"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-cn</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="62"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/zh/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>).</source>
        <translation>）。</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="28"/>
        <source>Search contents</source>
        <translation>搜索范围</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="36"/>
        <source>Default search engine</source>
        <translation>默认搜索引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="44"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>通过搜索关键词，可跳转到的默认搜索引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="60"/>
        <source>Default search engine is</source>
        <translation>默认搜索引擎为</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="69"/>
        <source>Google</source>
        <translation>谷歌</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="70"/>
        <source>Baidu</source>
        <translation>百度</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="71"/>
        <source>Bing</source>
        <translation>必应</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Yahoo</source>
        <translation>雅虎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="73"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="74"/>
        <source>360 AI Search</source>
        <translation>360AI搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="75"/>
        <source>Sogou</source>
        <translation>搜狗</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="76"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="97"/>
        <source>You need to use &quot;%0&quot; to replace the keyword in the URL</source>
        <translation>需要使用 “%0” 来替换URL中关键词</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="161"/>
        <source>Invalid URL</source>
        <translation>URL格式错误</translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/web/statictextworker.cpp" line="55"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>通过浏览器搜索“%1”</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="18"/>
        <source>Tailer settings</source>
        <translation>拖尾设置</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="28"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>搜索结果尾部显示，用于辅助识别搜索结果或区分重名项。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="41"/>
        <source>Parent directory</source>
        <translation>上级目录</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
        <source>Time modified</source>
        <translation>最近修改时间</translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="57"/>
        <source>Artist:</source>
        <translation>歌手：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="69"/>
        <source>Album:</source>
        <translation>专辑：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="94"/>
        <source>Duration:</source>
        <translation>时长：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="109"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="121"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
        <source>Time modified:</source>
        <translation>修改时间：</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="53"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="69"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="84"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Time modified:</source>
        <translation>修改时间：</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
        <source>Applications</source>
        <translation>应用</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
        <source>Folders</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
        <source>Web</source>
        <translation>Web搜索</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="34"/>
        <source>AI Search</source>
        <translation>AI搜索</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="26"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="27"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="28"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="29"/>
        <source>Duration:</source>
        <translation>时长：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="30"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="31"/>
        <source>Time modified:</source>
        <translation>修改时间：</translation>
    </message>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/file/filesearchutils.cpp" line="203"/>
        <source>modified</source>
        <translation>修改</translation>
    </message>
</context>
</TS>
